@@ -1,6 +1,7 @@
 
-#define DEBUG 0
+//#define DEBUG 0
 
+#include <klocale.h>
 #include <malloc.h>
 #include <kdebug.h>
 
@@ -20,6 +21,7 @@ extern "C" {
 #include "oconfig.h"
 
 extern FILE *xfopen(const char *filename, const char *type);
+extern void oops(QString message);
 
 /** We try for a VF first because that's what dvips does.  Also, it's
  *  easier to avoid running MakeTeXPK if we have a VF this way.  */
@@ -61,7 +63,9 @@ extern int n_files_left;
 
 font::font(char *nfontname, float nfsize, long chk, int mag, double dconv)
 {
+#ifdef DEBUG_FONT
   kdDebug() << "constructing font " << nfontname << " at " << (int) (nfsize + 0.5) << " dpi" << endl;
+#endif
 
   fontname   = nfontname;
   fsize      = nfsize;
@@ -75,7 +79,9 @@ font::font(char *nfontname, float nfsize, long chk, int mag, double dconv)
 
 font::~font()
 {
+#ifdef DEBUG_FONT
   kdDebug() << "discarding font " << fontname << " at " << (int)(fsize + 0.5) << " dpi" << endl;
+#endif
 
   free(fontname);
 
@@ -117,7 +123,9 @@ font::~font()
 
 unsigned char font::load_font(void)
 {
+#ifdef DEBUG_FONT
   kdDebug() << "loading font " <<  fontname << " at " << (int) (fsize + 0.5) << " dpi" << endl;
+#endif
 
   int	 dpi      = (int)(fsize + 0.5);
   char	*font_found;
@@ -127,33 +135,33 @@ unsigned char font::load_font(void)
   flags |= font::FONT_LOADED;
   file = font_open(fontname, &font_found, (double)fsize, &size_found, &filename);
   if (file == NULL) {
-    kdError() << "Can't find font " << fontname << "." << endl;
+    kdError() << i18n("Can't find font ") << fontname << "." << endl;
     return True;
   }
   --n_files_left;
   if (font_found != NULL) {
-    kdError() << "Can't find font " << fontname << "; using " << font_found << " instead at " << dpi << " dpi." << endl;
+    kdError() << QString(i18n("Can't find font %1; using %2 instead at %3 dpi.")).arg(fontname).arg(font_found).arg(dpi) << endl;
     free(fontname);
     fontname = font_found;
   }
   else
     if (!kpse_bitmap_tolerance ((double) size_found, fsize))
-      kdError() << "Can't find font " << fontname << " at " << dpi << " dpi; using " << size_found << " dpi instead." << endl;
+      kdError() << i18n("Can't find font %1 at %2 dpi; using %3 dpi instead.\n").arg(fontname).arg(dpi).arg(size_found);
   fsize      = size_found;
   timestamp  = ++current_timestamp;
-  set_char_p = set_char;
+  set_char_p = &dviWindow::set_char;
   magic      = two(file);
 
   if (magic == PK_MAGIC)
     read_PK_index();
   else
     if (magic == GF_MAGIC)
-      oops("The GF format for font file %s is no longer supported", filename);
+      oops(QString(i18n("The GF format for font file %1 is no longer supported")).arg(filename) );
     else
       if (magic == VF_MAGIC)
 	read_VF_index();
       else
-	oops("Cannot recognize format for font file %s", filename);
+	oops(QString(i18n("Cannot recognize format for font file %1")).arg(filename) );
 
   return False;
 }
@@ -165,11 +173,13 @@ unsigned char font::load_font(void)
 
 void font::mark_as_used(void)
 {
+#ifdef DEBUG_FONT
+  kdDebug() << "marking font " << fontname << " at " << (int) (fsize + 0.5) << " dpi" << endl;
+#endif
+
   if (flags & font::FONT_IN_USE) 
     return;
 
-  kdDebug() << "marking font " << fontname << " at " << (int) (fsize + 0.5) << " dpi" << endl;
-
   flags |= font::FONT_IN_USE;
 
   // For virtual fonts, also go through the list of referred fonts
@@ -191,7 +201,7 @@ struct glyph *font::glyphptr(unsigned int ch) {
   struct glyph *g = glyphtable+ch;
   if (g->bitmap.bits == NULL) {
     if (g->addr == 0) {
-      kdError() << "Character " << ch << " not defined in font " << fontname << endl;
+      kdError() << i18n("Character %1 not defined in font %2").arg(ch).arg(fontname) << endl;
       g->addr = -1;
       return NULL;
     }
@@ -201,7 +211,7 @@ struct glyph *font::glyphptr(unsigned int ch) {
     if (file == NULL) {
       file = xfopen(filename, OPEN_MODE);
       if (file == NULL) {
-	oops("Font file disappeared: %s", filename);
+	oops(QString(i18n("Font file disappeared: %1")).arg(filename) );
 	return NULL;
       }
     }
