@@ -19,15 +19,15 @@
 class MarkListTableItem
 {
 public:
-    MarkListTableItem( const char *s,
-		       const char *t) : marked(0), selected(0)  { _text = s; 
+    MarkListTableItem( const QString & s,
+		       const QString & t) : marked(0), selected(0)  { _text = s; 
 		       _tip = t;}
 	void	setMark( bool flag )	{ marked = flag; }
 	bool	mark()			{ return marked; }
 	void	setSelect( bool flag )	{ selected = flag; }
 	bool	select()		{ return selected; }
-	const char *text()		{ return _text.data(); }
-	const char *tip()               { return _tip.data(); }
+	QString text()		{ return _text; }
+	QString tip()               { return _tip; }
     private:
 	bool	marked;
 	bool	selected;
@@ -41,14 +41,14 @@ class MarkListTable: public QTableView
 
 public:
 	MarkListTable( QWidget * parent = 0, const char * name = 0 );
-	~MarkListTable() { }
-	QStrList *	markList();
-	void	insertItem ( const char *text, int index=-1,
+	~MarkListTable();
+	QStringList	markList();
+	void	insertItem ( const QString & text, int index=-1,
 			     const QString &tip = QString::null);
 	void	setAutoUpdate ( bool enable );
 	void	clear();
 	int	rowHeight();
-	const char *text( int index );
+	QString text( int index );
 	
 	QColor selectColor;
 	QColor selectTextColor;
@@ -64,7 +64,7 @@ public slots:
 
 signals:
 	void	selected( int index );
-	void	selected( const char * text );
+	void	selected( const QString & text );
 
 protected:
 	void	mousePressEvent ( QMouseEvent* );
@@ -93,13 +93,13 @@ class MarkList: public QWidget
 public:
 	MarkList( QWidget * parent = 0, const char * name = 0 );
 	~MarkList() { }
-	QStrList *	markList();
-	void	insertItem ( const char *text, int index=-1,
+	QStringList	markList();
+	void	insertItem ( const QString &text, int index=-1,
 			     const QString &tip = QString::null);
 	void	setAutoUpdate ( bool enable );
 	void	clear();
 	void 	setSelectColors( QColor bg, QColor fg );
-	const char *text( int index );
+	QString text( int index );
 	
 public slots:
 	void	select(int index);
