@@ -28,20 +28,20 @@ KViewShell::KViewShell(QString partname, KAboutData *about)
   // create the viewer part
 
   // Try to load
-  KLibFactory *factory = KLibLoader::self()->factory("libkviewpart");
+  KLibFactory *factory = KLibLoader::self()->factory("libkviewerpart");
   if (factory)
   {
     QStringList args;
     args << _partname;
-    view = (KViewPart*) factory->create(this, "kviewpart", "KViewPart", args);
+    view = (KViewPart*) factory->create(this, "kviewerpart", "KViewPart", args);
   }
   else
     {
-      KMessageBox::error(this, "No libkviewpart found !");
+      KMessageBox::error(this, "No libkviewerpart found !");
       exit(-1);
     }
 
-  setView(view->widget());
+  setCentralWidget(view->widget());
 
 
   // file menu
@@ -56,15 +56,12 @@ KViewShell::KViewShell(QString partname, KAboutData *about)
 
   m_helpMenu = new KHelpMenu( this, about, true, actionCollection() );
 
-  setXMLFile( locate( "config", "ui/ui_standards.rc" ) );
-  setXMLFile( "kviewshell.rc", true );
+  setXMLFile( "kviewshell.rc" );
 
   createGUI(view);
 
   readSettings();
 
-  resize (600,300);
-
   checkActions();
 
   setAcceptDrops(true);
@@ -105,6 +102,10 @@ void KViewShell::readSettings()
   showstatusbar->setChecked (config->readBoolEntry ("ShowStatusBar", true));
   slotShowStatusBar();
 
+  int w = config->readNumEntry ("WindowWidth", 600);
+  int h = config->readNumEntry ("WindowHeight", 300);
+  resize(w, h);
+
   recent->loadEntries(config, QString("%1-RecentFiles").arg(_partname));
 }
 
@@ -117,6 +118,8 @@ void KViewShell::writeSettings()
 
   config->writeEntry ("ShowToolBar", showtoolbar->isChecked());
   config->writeEntry ("ShowStatusBar", showstatusbar->isChecked());
+  config->writeEntry ("WindowWidth", width());
+  config->writeEntry ("WindowHeight", height());
 
   recent->saveEntries(config, QString("%1-RecentFiles").arg(_partname));
 
